@@ -127,6 +127,11 @@ PortalSession::PortalSession()
 
 PortalSession::~PortalSession()
 {
+    if (d->sessionPath.path().isEmpty()) {
+        qCDebug(KRDP) << "No portal session to close (session was never created)";
+        return;
+    }
+
     // Make sure to clear any modifier keys that were pressed when the session closed, otherwise
     // we risk those keys getting stuck and the original session becoming unusable.
     for (auto keycode : {KEY_LEFTCTRL, KEY_RIGHTCTRL, KEY_LEFTSHIFT, KEY_RIGHTSHIFT, KEY_LEFTALT, KEY_RIGHTALT, KEY_LEFTMETA, KEY_RIGHTMETA}) {
@@ -186,13 +191,12 @@ void PortalSession::sendEvent(const std::shared_ptr<QEvent> &event)
     }
     case QEvent::Wheel: {
         auto we = std::static_pointer_cast<QWheelEvent>(event);
-        auto delta = we->angleDelta();
-        if (delta.y() != 0) {
-            d->remoteInterface->NotifyPointerAxisDiscrete(d->sessionPath, QVariantMap{}, 0 /* Vertical */, delta.y() / 120);
-        }
-        if (delta.x() != 0) {
-            d->remoteInterface->NotifyPointerAxisDiscrete(d->sessionPath, QVariantMap{}, 1 /* Horizontal */, delta.x() / 120);
-        }
+        auto delta = we->pixelDelta();
+        // pixelDelta contains the scroll value already converted to
+        // degrees by InputHandler. The vertical axis is negated to
+        // account for the sign convention in
+        // xdg-desktop-portal-kde's requestPointerAxis.
+        d->remoteInterface->NotifyPointerAxis(d->sessionPath, QVariantMap{}, delta.x(), -delta.y());
         break;
     }
     case QEvent::KeyPress:
@@ -332,6 +336,8 @@ void KRdp::PortalSession::onSessionStarted(uint code, const QVariantMap &result)
             encodedStream->setNodeId(stream.nodeId);
             encodedStream->setFd(fd.takeFileDescriptor());
             encodedStream->setEncodingPreference(PipeWireBaseEncodedStream::EncodingPreference::Speed);
+            // Ensure we encode in full color range so FFmpeg decodes correctly.
+            encodedStream->setColorRange(PipeWireBaseEncodedStream::ColorRange::Full);
             encodedStream->setEncoder(PipeWireEncodedStream::H264Baseline);
             connect(encodedStream, &PipeWireEncodedStream::newPacket, this, &PortalSession::onPacketReceived);
             connect(encodedStream, &PipeWireEncodedStream::sizeChanged, this, &PortalSession::setSize);
